
/* 
* PLUGIN: Entex extended block attributes
*
* Version: 1.0
* Applies to Wordpress back-end
* Author: Jonas Lundman
* More information and documentation at
* http://entex.info
*
*/

// Updated 2021 07 19

wp.domReady(function(){ 

	wp.blocks.unregisterBlockStyle('core/image', 'rounded');
	wp.blocks.unregisterBlockStyle('core/image', 'default');

	var entex_add_styles = 0;
	if(!entex_add_styles) return;
	
	
	
	wp.blocks.registerBlockStyle('core/image', {
		name: 'ua-border',
		label: 'Border'
	});
	
	wp.blocks.registerBlockStyle('core/image', {
		name: 'ua-layer-caption',
		label: 'Layer caption'
	});
	
	
	wp.blocks.registerBlockStyle('core/paragraph', {
		name: 'ua-preamble',
		label: 'Preamble'
	});
	
	wp.blocks.registerBlockStyle('core/paragraph', {
		name: 'ua-indent',
		label: 'Indent'
	});
	
	wp.blocks.registerBlockStyle('core/paragraph', {
		name: 'ua-box',
		label: 'Content in box'
	});
	
	wp.blocks.registerBlockStyle('core/table', {
		name: 'ua-table-deviders',
		label: 'Devide table columns'
	});
	
	wp.blocks.registerBlockStyle('core/table', {
		name: 'ua-table-border',
		label: 'Border table'
	});
	
});

;(function($){
	$(document).ready(function(){
		
		var transported_1 = ENTEX_THEME_GUTENBERG_BACKEND.locations;
		var locations = $.parseJSON(transported_1);
		
		var transported_2 = ENTEX_THEME_GUTENBERG_BACKEND.positions;
		var positions = $.parseJSON(transported_2);
		
		var data = ENTEX_THEME_GUTENBERG_BACKEND.data;
		var Arr = $.parseJSON(data);
		
		/* Additional CSS */
		var txt_1 = ENTEX_THEME_GUTENBERG_BACKEND.txt_1;
		/* Theme Locations */
		var txt_2 = ENTEX_THEME_GUTENBERG_BACKEND.txt_2;
		/* Remove current widgets */
		var txt_3 = ENTEX_THEME_GUTENBERG_BACKEND.txt_3;
		/* Sections cant handle more then 4 columns. Create groups or use another location. */
		var txt_4 = ENTEX_THEME_GUTENBERG_BACKEND.txt_4;
		
		var def_cleanup = ENTEX_THEME_GUTENBERG_BACKEND.def_cleanup;
		var def_open = ENTEX_THEME_GUTENBERG_BACKEND.def_open;

		let blockLoaded = false;
		let blockLoadedInterval = setInterval(function(){
			if(document.getElementById('post-title-0')){
				blockLoaded = true;
				this_init();
			}
			if(blockLoaded){
				clearInterval(blockLoadedInterval);
			}
		}, 500);
		
		function this_init(){
			
			/* init Entex CSS classnames */
			$('.is-root-container').addClass('ua-main ua-content').parent().addClass('ua-root ua-init');
			
			/* void front-end template events and links */
			$(document).on('click', '.entex-block-content a', function(event){ return false; });
			
			if($('.editor-post-featured-image__container').get(0)){
				if($('#entex_post_thumbnail_border').is(':checked')) $('.editor-post-featured-image__container').addClass('ua-admin-set-border');
				if($('#entex_post_thumbnail_hide').is(':checked')) $('.editor-post-featured-image__container').addClass('ua-admin-set-hidden');
			}
			
			createLocatedInfo();
			
			$(document).on('click', '.block-editor-post-preview__button-resize', function(){
				if($(this).index() == 2){
					$('.is-root-container').addClass('ua-not-main').removeClass('ua-main');
				} else { 
					$('.is-root-container').addClass('ua-main').removeClass('ua-not-main');
				}
			});
			
			$(document).on('click', '#entex_post_thumbnail_border', function(){
				if($('#entex_post_thumbnail_border').is(':checked')){
					$('.editor-post-featured-image__container').addClass('ua-admin-set-border');
				} else { 
					$('.editor-post-featured-image__container').removeClass('ua-admin-set-border');
				}
			});
			
			$(document).on('click', '#entex_post_thumbnail_hide', function(){
				if($('#entex_post_thumbnail_hide').is(':checked')){
					$('.editor-post-featured-image__container').addClass('ua-admin-set-hidden');
				} else { 
					$('.editor-post-featured-image__container').removeClass('ua-admin-set-hidden');
				}
			});
			
			$(document).on('click', '.components-panel__body:not(.is-opened) .components-panel__body-toggle', function(){
				var $el = $(this).closest('.components-panel__body');
				/* metabox section */
				$('#side-sortables:visible > .postbox:not(.closed)').not('#entex-gutenberg-metabox').find('.postbox-header h2').trigger('click');
				$('#entex-gutenberg-metabox.closed').find('.postbox-header h2').trigger('click');
				/* post section */
				$el.siblings().filter('.is-opened').find('.components-panel__body-toggle').trigger('click');
				$('.interface-interface-skeleton__sidebar').stop().animate({ scrollTop: ($el.position().top) - ($('.interface-complementary-area-header').outerHeight()) }, 300);
			});
			
			$(document).on('click', '#side-sortables > .postbox:not(.closed) .postbox-header h2', function(){
				var $el = $(this).closest('.postbox');
				/* post section */
				$('.components-panel__body:visible').filter('.is-opened').find('.components-panel__body-toggle').trigger('click');
				/* metabox section */
				$el.siblings('.postbox').not('.closed').find('.postbox-header h2').trigger('click');
				$('.interface-interface-skeleton__sidebar').stop().animate({ scrollTop: ($el.offset().top) - ($('.interface-complementary-area-header').outerHeight()) }, 300);

			});
			
			$(document).on('click', '#normal-sortables > .postbox:not(.closed) .postbox-header h2', function(){
				var $el = $(this).closest('.postbox');
				$el.siblings('.postbox').not('.closed').find('.postbox-header h2').trigger('click');
				$('.interface-interface-skeleton__content').stop().animate({ scrollTop: ($el.offset().top) + ($('.edit-post-visual-editor').outerHeight() - 50) }, 300);

			});
			
			$(document).on('focus', '.editor-styles-wrapper .is-root-container', function(){
				let blockInspectorLoaded = false;
				let blockInspectorLoadedInterval = setInterval(function(){
					var button = $('.block-editor-block-inspector__advanced').find('.components-panel__body-toggle').get(0);
					if(button){
						blockInspectorLoaded = true;
						if($(button).is('.is-opened button')) $(button).trigger('click');
						if(def_cleanup){
							$('.components-panel__body-toggle[aria-expanded=true]').trigger('click');
							$('.components-resizable-box__container').removeAttr('class').removeAttr('style');
							//$('.components-base-control__help').remove();
						}
					}
					if(blockInspectorLoaded){
						clearInterval(blockInspectorLoadedInterval);
						if(def_open) $(button).trigger('click');
					}
				}, 300);
				
			});
			

			$(document).on('click', '.block-editor-block-inspector__advanced .components-panel__body-toggle', function(){
				
				let blockInspectorLoaded = false;
				let blockInspectorLoadedInterval = setInterval(function(){
					/* Additional CSS class(es) field */
					var input = $('.block-editor-block-inspector__advanced').find('.css-wdf2ti-Wrapper:last-child input').get(0);
					if(input){
						blockInspectorLoaded = true;
						createElementClear(input);
					}
					if(blockInspectorLoaded){
						clearInterval(blockInspectorLoadedInterval);
					}
				}, 300);
				
			});

		}
		
		function createLocatedInfo(){
			var $ed = $('.editor-styles-wrapper .is-root-container');
			var find = $ed.find('[class*=-location-]').get(0);
			if(!find) return;
			$('.editor-styles-wrapper .is-root-container').find('[class*=-location-]').each(function(){
				var $block = $(this);
				var classnames = $(this).attr('class');
				$.each(locations, function(location, name){
					if(classnames.match(location)){
						$block.attr('title', name).attr('data-location', name);
					}
				});
			});
			
		}
		
		function createElementClear(input){
			
			var $wrapper = $(input).closest('.components-base-control');
			if($wrapper.find('.entex-created-element').get(0)){
				$wrapper.find('.entex-created-element').remove();
			}
			
			//if(def_cleanup) $wrapper.parent().find('.components-base-control__help').remove();
			
			var $root = $('.editor-styles-wrapper .is-root-container');
			var node = $root.find('.is-selected').get(0);
			var element = node.nodeName.toLowerCase();
			var type = $(node).attr('data-type');
			
			var $wr = $('<div />').addClass('entex-created-element').css('margin', '1em 0');
			$wrapper.append($wr);
			
			var css = {
				'padding': '0.5em',
				'border-width': '1px',
				'border-style': 'dashed',
				'border-color': '#ccc'
			};
			
			var $pl = $('<div />').addClass('entex-created-position').css('display', 'none').css({
				'margin': '0.5em 0 0 0',
				'padding': '0.25em 0 0.5em 0',
				'border-width': '1px 0px 0px 0px',
				'border-style': 'dashed',
				'border-color': '#ccc'
			});
			
			var ref = {
				'display': 'block',
				'float': 'right',
				'height': '16px',
				'width': '16px',
				'margin': '1px 5px 0px 5px',
				'border-width': '1px',
				'border-style': 'solid',
				'border-color': '#ccc'
			};
			
			
			if(Arr[type] === undefined) var has_css = false;
				else var has_css = true;
				
			if(has_css){
			
			var $innerHTML = $('<div />').addClass('entex-created-group entex-created-additional').css(css).css('margin-bottom', '1em');
			var $headingHTML = $('<div />').addClass('entex-created-heading').css('margin', '0.5em 0 0.5em 0').text(txt_1);
			$wr.append($headingHTML, $innerHTML);
			$.each(Arr[type], function(classname, name){
				var valid = '*';
				if(Arr['is'][classname] !== undefined) valid = Arr['is'][classname];
				
				var $label = $('<label />').text(' ' + name).css('display', 'block').css('margin', '0.25em 0').data('validate', classname);
				var $el = $('<input type="checkbox" />');
				$label.prepend($el);
				$innerHTML.append($label.hide());
				var not_valid = false;
				if($(node).is(valid)) $label.show();
					else not_valid = true;

				var cls = classname;
				var initial = $(input).val();
				if(initial && initial.match(cls)){
					$el.prop('checked', true);
				}
				$el.on('click', function(){
					var value = $(input).val();
					if(!$(this).is(':checked')){
						var classes = value.split(' ').filter(function(c) {
							return c.lastIndexOf(cls, 0) !== 0;
						});
						classes = classes.join(' ').trim();
					} else {
						var classes = value + ' ' + cls;
					}
					var native = Object.getOwnPropertyDescriptor(window.HTMLInputElement.prototype, 'value').set;
					native.call(input, classes);
					input.dispatchEvent(new Event('input', {'bubbles': true}));
						
					$innerHTML.find('label').each(function(){
						var validated = '*';
						var validate = $(this).data('validate'); 
						if(Arr['is'][validate] !== undefined) validated = Arr['is'][validate];
						if($(node).is(validated)){
							$(this).show();
						} else {
							$(this).find('input').prop('checked', false);
							$(this).hide();
						}
					});
						
				});
					
				if(not_valid && $el.is(':checked')){ 
					$el.trigger('click'); 
				}
			});
			}
			
			
			if($(node).is('.is-root-container > *')){
				
			var $innerLocations = $('<div />').addClass('entex-created-group').css(css);
			var $headingLocations = $('<div />').addClass('entex-created-heading').css('margin', '0 0 0.5em 0').text(txt_2);
			$wr.append($headingLocations, $innerLocations);
			$.each(locations, function(location, name){
				
				var $label = $('<label />').text(' ' + name).css('display', 'block').css('margin', '0.25em 0');
				var $monitor = $('<span />').text('').css('display', 'block').css('float', 'right').css('margin-left', '5px').attr('data-location', location);
				var $el = $('<input type="checkbox" />').attr('id', location);
				$label.prepend($el);
				$innerLocations.append($label.append($monitor));
				
				var disable = false;
				var added = $('.editor-styles-wrapper .is-root-container').find('.' + location).get();
				if(added.length) {
					var monited = added.length;
					if(location.match('-section-') && monited == 4) disable = true;
					$(added.reverse()).each(function(){
						var $dom = $(this);
						var $reference = $('<span />').text('').css(ref).attr('title', $dom.attr('data-type'));
						$reference.click(function(){
							$dom.focus();
							return false;
						});
						$label.append($reference);
					});
				} else var monited = '0';
				$monitor.text(monited);
				
				if(location == 'entex-location-sidebar'){
					$el.val(location);
				} else $el.val('');

				var cls = location;
				var initial = $(input).val();
				var init = false;
				if(initial && initial.match(cls)){
					$el.prop('checked', true);
					init = true;
				}
				$el.on('click', function(){
					var value = $(input).val();
					if(!$(this).is(':checked')){ 
						var classes = value.split(' ').filter(function(c) {
							return c.lastIndexOf(cls, 0) !== 0;
						});
						classes = classes.join(' ').trim();
						/* content */
						$(node).removeAttr('title').removeAttr('data-location');
						
						if($(this).val() == 'entex-location-sidebar'){
							var $box = $(this).parent().next('.entex-created-position');
							if($box.find(':checked')){
								$box.find(':checked').prop('checked', false);
								classes = classes.replace('entex-position-replace', '').trim();
							}
							$box.slideUp('fast');
						}
					} else {
						if(disable){
							alert(txt_4);
							return false;
						}
						var classes = value + ' ' + cls;
						if($(this).val() == 'entex-location-sidebar'){
							$(this).parent().next('.entex-created-position').slideDown('fast').find('input').prop('checked', false).parent().css('opacity', '');
						}
						/* content */
						$(node).attr('title', name).attr('data-location', name);
					}
					var native = Object.getOwnPropertyDescriptor(window.HTMLInputElement.prototype, 'value').set;
					native.call(input, classes);
					input.dispatchEvent(new Event('input', {'bubbles': true}));
					createElementClear(input);
				});
				
				if(location == 'entex-location-sidebar'){
					
					var pl_name = txt_3;
					var $pl_label = $('<label />').text(' ' + pl_name).css('display', 'block').css('margin', '0.25em 0 0.5em 0');
					var $pl_el = $('<input type="checkbox" />').attr('id', 'entex-remove-current-widgets');
					$pl_label.prepend($pl_el);
					$innerLocations.append($pl.append($pl_label));
					if(init) $pl.show();

					initial = $(input).val();
					if(initial && initial.match('entex-position-replace')){
						$pl_el.prop('checked', true);
					}
					
					$pl_el.data('monitored', 0);
					if($('.is-root-container .entex-position-replace').get(0)){
						var $repo = $('<span />').text('A').css('display', 'block').css('float', 'right').click(function(){
							$($('.is-root-container .entex-position-replace').get(0)).focus();
							return false;
						});
						$pl_label.append($repo);
						$pl.show();
						
						if(!$pl_el.prop('checked')){
							$pl_label.css('opacity', '0.5');
							$pl_el.prop('checked', true).data('monitored', 1);
						}
					}
					
					$pl_el.on('click', function(){
						var recheck = 0;
						if(!$('#entex-location-sidebar').is(':checked')) return false;
						if($(this).data('monitored')){
							$(this).data('monitored', 0).parent().css('opacity', '');
							recheck = 1;
						}
						var pl_value = $(input).val();
						if(!$(this).is(':checked') && !recheck){
							var pl_classes = pl_value.split(' ').filter(function(c) {
								return c.lastIndexOf('entex-position-replace', 0) !== 0;
							});
							pl_classes = pl_classes.join(' ').trim();
						} else {
							var pl_classes = pl_value + ' ' + 'entex-position-replace';
							if(recheck) $(this).prop('checked', true);
						}
						var pl_native = Object.getOwnPropertyDescriptor(window.HTMLInputElement.prototype, 'value').set;
						pl_native.call(input, pl_classes);
						input.dispatchEvent(new Event('input', {'bubbles': true}));
					});
					
				}
			});
			
			} else {
				$.each(locations, function(location, name){
					var cls = location;
					var initial = $(input).val();
					if(initial && initial.match(cls)){
						var value = $(input).val();
						var classes = value.split(' ').filter(function(c) {
							return c.lastIndexOf(cls, 0) !== 0;
						});
						classes = classes.join(' ').trim();
						var native = Object.getOwnPropertyDescriptor(window.HTMLInputElement.prototype, 'value').set;
						native.call(input, classes);
						input.dispatchEvent(new Event('input', {'bubbles': true}));
					}
				});
			}
			

		}

	});

})(jQuery);
