<?php if(!defined('ABSPATH')) die();
/**
 * Entex Theme Gutenberg functions and definitions
 * This file is never loaded if classic editor interface is in use
 * Most of WordPress backend doesnt use Gutenberg
 * Thats why entex_is_gutenberg() is checking if we are on a Gutenberg pageload
 *
 * Version: 2.10710
 *
 * Documentation: http://entex.info
 * Author: Jonas Lundman
 *
**/



/* -------------------- */
// LOAD ADMIN BACKEND ASSETS

function entex_admin_gutenberg_enqueue_style(){
	if(entex_is_gutenberg() && defined('ENTEX_GUTENBERG_CLEANUP')){
		/* pure css */
		wp_enqueue_style('entex-theme-admin-backend-gutenberg', get_template_directory_uri() .'/assets/css/entex-theme-admin-backend-gutenberg.css');
	}
}
add_action('admin_enqueue_scripts', 'entex_admin_gutenberg_enqueue_style', 30);


/* -------------------- */
// GUTENBERG WRAPPER
/* global backend only */

function entex_admin_gutenberg_styles() {

	if(!entex_is_gutenberg()) return;
	
	$add = '';
	$text_group_begins = esc_html_x('Group begins', 'Admin', 'entex');
	
	/* tmp */
	$add .= '.is-style-ua-border img { display: block; border-width: 1px 1px 1px 1px; border-style: solid; border-color: inherit; border-radius: 0px; }';
	$add .= '.wp-block-cover.is-style-ua-border { border-width: 1px 1px 1px 1px; border-style: solid; border-color: inherit; border-radius: 0px; }';
	
	if(defined('ENTEX_THEME_EDIT_CONTENT_WIDTH')) $width = ENTEX_THEME_EDIT_CONTENT_WIDTH;
		else $width = 640;
	
	/* critical */
	$add .= 'html { font-size: 16px !important; } ';
	$add .= 'html .wp-block { max-width: '. $width .'px; } ';
	$add .= 'html .editor-styles-wrapper { line-height: 1.375; } ';
	
	/* Scenarios when parent cant be focused, Gutenberg architecure BUG */
	$add .= '.wp-block-columns { padding-top: 1em !important; } ';
	$add .= 'html figure > .components-button-group { margin: 0.5em; } ';
	$add .= '.wp-block-group:before { border-width: 5px 0px 0px 0px; border-style: dotted; content: "'. $text_group_begins .'"; display: block; padding: 0.5em; color: #888; background-color: #f5f5f5; text-align: center; } ';
	$add .= '.wp-block-group { margin-top: 3em !important; margin-bottom: 3em !important; padding-bottom: 1em !important; border-width: 0px 0px 5px 0px !important; border-style: dotted !important; border-color: #f0f0f0 !important; } ';
	
	/* located content */
	$add .= 'html .editor-styles-wrapper [class*=-location-] { background-color: rgba(0,255,0,0.05); padding: 10px; border: 1px dashed #dbdbdb; } ';

	/* IMAGE width & height manual fields */
	if(defined('ENTEX_GUTENBERG_CLEANUP')){
		$add .= '.block-editor-image-size-control { display: none; } ';
	}
	
	/* Resize handle wrapper */
	if(defined('ENTEX_GUTENBERG_CLEANUP')){
		$add .= '.editor-styles-wrapper .wp-block-image .components-resizable-box__container > div { display: none !important; } ';
	}
	
	wp_register_style('entex-gutenberg-style', false);
	wp_enqueue_style('entex-gutenberg-style');
	wp_add_inline_style('entex-gutenberg-style', $add);
}
add_action('admin_head', 'entex_admin_gutenberg_styles');





/* -------------------- */
// MIMIC TEMPLATE BODY CLASS
function entex_theme_filter_gutenberg_admin_body_class($classnames){
	
	if(!entex_is_gutenberg()) return;
	
	$classes[] = 'entex-theme';
	$classes[] = 'wp-is-'.entex_fn_lowercase(get_bloginfo('language'));
	$classes[] = 'wp-is-singular';

	if(current_user_can('manage_options')) $classes[] = 'wp-user-is-administrator';
	if(current_user_can('manage_categories')) $classes[] = 'wp-user-is-editor';
	
	$initial = entex_theme_load_initial_styles();
	if($initial && !defined('ENTEX_THEME_DISABLE_INITIAL_TYPO')) $classes[] = 'wp-is-initial';
	
	$classnames .= ' '. implode(' ', $classes);
	return $classnames;
}
add_filter('admin_body_class', 'entex_theme_filter_gutenberg_admin_body_class');






/* -------------------- */
// GUTENBERG FILTER FRONT-END BLOCKS
/* font-end only */

function entex_theme_render_block_core($block_content, $block){
	
	if(is_admin()) return $block_content;
	if(apply_filters('entex_theme_render_block_default', false)) return $block_content;
	static $group = 0;

	if($block['blockName'] == 'core/preformatted') return $block_content;
	if($block['blockName'] == 'core/archives'){
		$block_content = '<div class="ua-set-nav-list">'. $block_content .'</div>';
	}
	if($block['blockName'] == 'core/latest-comments'){
		$block_content = '<div class="ua-set-nav-list ua-wrapper">'. $block_content .'</div>';
	}
	if($block['blockName'] == 'core/latest-posts'){
		$block_content = '<div class="ua-set-nav-list">'. $block_content .'</div>';
	}
	if($block['blockName'] == 'core/rss'){
		$block_content = '<div class="ua-set-nav-list">'. $block_content .'</div>';
	}
	if($block['blockName'] == 'core/calendar'){
		$block_content = str_replace('<div class="wp-block-calendar', '<div class="wp-block-calendar widget_calendar', $block_content);
	}
	if($block['blockName'] == 'core/group'){
		$group = 1;
		$block_content = str_replace('wp-block-group__inner-container', 'wp-block-group__inner-container ua-content', $block_content);
	}
	
	if($block['blockName'] == 'core/image'){
		if(strpos($block_content, 'alignleft') !== FALSE){
			$block_content = str_replace('<div class="wp-block-image', '<div data-align="left" class="wp-block-image', $block_content);
		}
		if(strpos($block_content, 'alignright') !== FALSE){
			$block_content = str_replace('<div class="wp-block-image', '<div data-align="right" class="wp-block-image', $block_content);
		}
	}
	if($block['blockName'] == 'core/columns'){
		$tmp = str_replace('wp-block-columns', '', $block_content);
		if(count(explode('wp-block-column', $tmp)) > 3){
			$block_content = str_replace('wp-block-columns', 'wp-block-columns ua-block-wrap', $block_content);
		}
		$block_content = str_replace('wp-block-column', 'ua-block-column', $block_content);
	}
	
	$block_content = str_replace('is-style-ua-layer-caption', 'ua-layer-caption', $block_content);
	$block_content = str_replace('is-style-ua-layer-heading', 'ua-layer-heading', $block_content);
	$block_content = str_replace('is-style-ua-border', 'ua-border', $block_content);
	$block_content = str_replace('is-style-ua-clear', 'ua-clear', $block_content);
	$block_content = str_replace('has-small-font-size', 'ua-not-main', $block_content);
	
	/* CIRCUT on parsing in entex-template-selector.php MAYBE: we there remove the filter on current function */
	if(isset($GLOBALS['ENTEX-SIDEBAR-BLOCKS-PARSING']) && $GLOBALS['ENTEX-SIDEBAR-BLOCKS-PARSING']) return $block_content;
	
	if($block['blockName'] == 'core/paragraph'){
		if(strpos($block_content, 'is-style-ua-preamble') !== FALSE){
			$post_id = get_the_ID();
			/* filter */
			if(!apply_filters('entex_theme_render_block_preamble_'. $post_id, true)) $block_content = '';
		}
	}
	
	if(isset($block['attrs']['className']) && $block['attrs']['className']){
		if(isset($GLOBALS['ENTEX-SIDEBAR-BLOCKS-REMOVE'][$block['attrs']['className']])){
			$block_content = '';
		} else if(!is_singular()){
			$classnames = $block['attrs']['className'];
			$locations = array_keys(array_merge(apply_filters('entex_theme_locations', array()), array('entex-location-sidebar' => 'Current sidebar')));
			foreach($locations as $match){
				if(strpos($classnames, $match) !== FALSE){
					$block_content = '';
				}
			}
		}
	}

	return $block_content;
}
add_filter('render_block', 'entex_theme_render_block_core', 10, 2);



function entex_theme_gutenberg_backend_css(){
	
	if(!entex_is_gutenberg()) return;
	wp_register_style('entex-theme-gutenberg-backend', get_template_directory_uri() .'/assets/ua-css/entex-gutenberg-backend.min.css');
	wp_enqueue_style('entex-theme-gutenberg-backend');
	
	$G_CSS = get_theme_mod('entex_gutenberg_styles', array());
	if(!empty($G_CSS)){
		foreach($G_CSS as $_TARGET => $styles){
			foreach($styles as $style){
				if($style && trim($style)){
					$css = '';
					if($_TARGET == 'html'){
						
						$style = str_replace('body, .ua-nav li li, figcaption, html > body .ua-not-main {', 'div.ua-root[class*=ua-root], div.ua-root[class*=ua-root] .ua-nav li li, div.ua-root[class*=ua-root] figcaption, html > body div.ua-root[class*=ua-root] .ua-not-main {', $style);
						$style = str_replace('body, .ua-nav li li {', 'div.ua-root[class*=ua-root], div.ua-root[class*=ua-root] .ua-nav li li {', $style);
						$style = str_replace('.ua-main, .ua-main .ua-nav li li {', 'div.ua-root[class*=ua-root] .ua-main, div.ua-root[class*=ua-root] .ua-main .ua-nav li li {', $style);
						$style = str_replace('.ua-init th, .ua-init strong, p.ua-preamble:not(:only-child), .ua-comment-list div[class*=-meta] [rel=nofollow], .ua-comment-list p.moderate', '.ua-root[class*=ua-root] th, .ua-root[class*=ua-root] strong, .ua-root[class*=ua-root] p strong', $style);
						$style = str_replace('html {', 'div.editor-styles-wrapper[class*=editor-styles-wrapper]:not(.whatever) {', $style);
						$style = str_replace('p {', '.ua-root[class*=ua-root] p {', $style);
						
						$css = $style;
					}
					
					if($_TARGET == 'h1'){
						$style = str_replace('h1', '#editor .wp-block.editor-post-title', $style);
						$css = $style;
					}
					
					if($_TARGET == 'h1_span'){
						$style = str_replace('#main-header h1 span', '#editor .wp-block.editor-post-title textarea', $style);
						$css = $style;
					}
				
					if($_TARGET == 'h1_em'){
						$style = str_replace('h1 em', '#editor .wp-block.editor-post-title .extended', $style);
						$css = $style;
					}
					
					if($_TARGET == 'h2'){
						$style = str_replace('.entex-theme h2', '.entex-theme div.ua-root h2', $style);
						$style = str_replace('html > body.entex-theme .ua-not-main h2', 'html > body.entex-theme div.ua-root .ua-not-main h2', $style);
						$style = str_replace('.entex-theme .ua-main h2', '.entex-theme div.ua-root .ua-main h2', $style);
						$css = $style;
					}
					
					if($_TARGET == 'h2_span'){
						$style = str_replace('.entex-theme .entry-heading', '.entex-theme div.ua-root .entry-heading', $style);
						$style = str_replace('html > body.entex-theme .ua-not-main .entry-heading', 'html > body.entex-theme div.ua-root .ua-not-main .entry-heading', $style);
						$style = str_replace('.entex-theme .ua-main .entry-heading', '.entex-theme div.ua-root .ua-main .entry-heading', $style);
						$css = $style;
					}
					
					if($_TARGET == 'h3'){
						$style = str_replace('.entex-theme h3', '.entex-theme div.ua-root h3', $style);
						$style = str_replace('html > body.entex-theme .ua-not-main h3', 'html > body.entex-theme div.ua-root .ua-not-main h3', $style);
						$style = str_replace('.entex-theme .ua-main h3', '.entex-theme div.ua-root .ua-main h3', $style);
						$css = $style;
					}
					
					if($_TARGET == 'h4'){
						$style = str_replace('.entex-theme h4', '.entex-theme div.ua-root h4', $style);
						$css = $style;
					}
					
					if($_TARGET == 'preamble'){
						$style = str_replace('.entex-theme p.is-style-ua-preamble', '.entex-theme div.ua-root p.is-style-ua-preamble', $style);
						$style = str_replace('html > body.entex-theme .ua-not-main p.is-style-ua-preamble', 'html > body.entex-theme div.ua-root .ua-not-main p.is-style-ua-preamble', $style);
						$style = str_replace('.entex-theme .ua-main p.is-style-ua-preamble', '.entex-theme div.ua-root .ua-main p.is-style-ua-preamble', $style);
						$css = $style;
					}

					if($css) wp_add_inline_style('entex-theme-gutenberg-backend', $css);
				}
			}
		}
	}
	
	$add = '';
	$add .= 'html .acf-block-panel .acf-label { display: none; } ';
	$add .= 'html .acf-block-panel p.description { display: none; } ';
	$add .= 'html .block-editor .edit-post-sidebar .acf-fields > .acf-field-true-false + .acf-field-true-false { margin-top: -1em; } ';
	$add .= '.ua-content .acf-block-fields input { margin-top: 0px; } ';
	
	wp_add_inline_style('entex-theme-gutenberg-backend', $add);
	
}
add_action('admin_footer', 'entex_theme_gutenberg_backend_css', 9999);




function entex_theme_gutenberg_editor_scripts(){

	$fonts_url = entex_theme_fonts_url();
	if($fonts_url) wp_enqueue_style('entex-theme-fonts', $fonts_url, array(), null);
	
	$fonts_url = entex_theme_customize_fonts_url();
	if($fonts_url) wp_enqueue_style('entex-theme-fonts-customizer', $fonts_url, array(), null);
	
	$version = filemtime(get_template_directory().'/assets/js/entex-theme-gutenberg.js');

	$handle = 'entex-theme-gutenberg';
	wp_enqueue_script($handle, get_template_directory_uri() .'/assets/js/entex-theme-gutenberg.js', array('jquery', 'wp-blocks', 'wp-element', 'wp-components', 'wp-i18n'), $version, true);
	
	/* pass Theme locations */
	$A = array_merge(array('entex-location-sidebar' => esc_html_x('Current sidebar', 'Template locations', 'entex')), apply_filters('entex_theme_locations', array()));
	if(entex_is_gutenberg() && isset($A['entex-location-shortcode'])) unset($A['entex-location-shortcode']);
	$locations = json_encode($A);
	
	/* pass Theme placement for location Current sidebar */
	$A = apply_filters('entex_theme_current_sidebar_position', array());
	$positions = json_encode($A);
	
	/* pass Theme classnames */
	$B['core/paragraph'] = apply_filters('entex_editor_core/paragraph', array());
	$B['core/image'] = apply_filters('entex_editor_core/image', array());
	$B['core/table'] = apply_filters('entex_editor_core/table', array());
	$B['core/cover'] = apply_filters('entex_editor_core/cover', array());
	$B['core/group'] = apply_filters('entex_editor_core/group', array());

	/* pass Valid classnames for specific DOM element */
	$B['is'] = apply_filters('entex_editor_validate', array());
	$data = json_encode($B);
	
	$def_open = '';
	$def_cleanup = '';
	
	if(defined('ENTEX_GUTENBERG_CLEANUP')){
		$def_open = '1';
		$def_cleanup = '1';
	}

	wp_localize_script($handle, 'ENTEX_THEME_GUTENBERG_BACKEND', array(
		'txt_1' => esc_html_x('Additional CSS', 'Gutenberg metabox', 'entex'),
		'txt_2' => esc_html_x('Theme Locations', 'Gutenberg metabox', 'entex'),
		'txt_3' => esc_html_x('Remove current widgets', 'Gutenberg metabox', 'entex'),
		'txt_4' => esc_html_x('Sections cant handle more then 4 columns. Create groups or use another location.', 'Gutenberg metabox', 'entex'),
		'def_open' => $def_open,
		'def_cleanup' => $def_cleanup,
		'data' => $data,
		'locations' => $locations,
		'positions' => $positions
	));
}
add_action('enqueue_block_editor_assets', 'entex_theme_gutenberg_editor_scripts');



function entex_editor_add_core_paragraph($obj){
	$obj['is-style-ua-preamble'] 	= 	esc_html_x('Preamble', 'Gutenberg metabox', 'entex');
	$obj['is-style-ua-indent'] 		= 	esc_html_x('Indent', 'Gutenberg metabox', 'entex');
	$obj['is-style-ua-indent-cite'] = 	esc_html_x('Indent Cite', 'Gutenberg metabox', 'entex');
	$obj['is-style-ua-box'] 		= 	esc_html_x('Content in box', 'Gutenberg metabox', 'entex');
	$obj['is-style-ua-box-border'] 	= 	esc_html_x('Border on box', 'Gutenberg metabox', 'entex');
	$obj['ua-text-shadow-light'] 	= 	esc_html_x('Text shadow light', 'Gutenberg metabox', 'entex');
	$obj['ua-text-shadow-dark'] 	= 	esc_html_x('Text shadow dark', 'Gutenberg metabox', 'entex');
	$obj['ua-cover-column'] 		= 	esc_html_x('Cover column', 'Gutenberg metabox', 'entex');
	return $obj;
}
add_filter('entex_editor_core/paragraph', 'entex_editor_add_core_paragraph', 10, 1);

function entex_editor_add_core_image($obj){
	$obj['is-style-ua-border'] 			= 	esc_html_x('Border', 'Gutenberg metabox', 'entex');
	$obj['is-style-ua-layer-caption'] 	= 	esc_html_x('Layer caption', 'Gutenberg metabox', 'entex');
	$obj['is-style-ua-layer-heading'] 	= 	esc_html_x('Layer heading', 'Gutenberg metabox', 'entex');
	$obj['ua-cover-column'] 			= 	esc_html_x('Cover column', 'Gutenberg metabox', 'entex');
	return $obj;
}
add_filter('entex_editor_core/image', 'entex_editor_add_core_image', 10, 1);

function entex_editor_add_core_table($obj){
	$obj['is-style-ua-table-border'] 	= 	esc_html_x('Border', 'Gutenberg metabox', 'entex');
	$obj['is-style-ua-table-deviders'] 	= 	esc_html_x('Deviders', 'Gutenberg metabox', 'entex');
	return $obj;
}
add_filter('entex_editor_core/table', 'entex_editor_add_core_table', 10, 1);

function entex_editor_add_core_cover($obj){
	$obj['is-style-ua-border'] 			= 	esc_html_x('Border', 'Gutenberg metabox', 'entex');
	$obj['ua-layer-text'] 				= 	esc_html_x('Layer text', 'Gutenberg metabox', 'entex');
	$obj['is-style-ua-layer-heading'] 	= 	esc_html_x('Layer heading', 'Gutenberg metabox', 'entex');
	$obj['ua-cover-column'] 			= 	esc_html_x('Cover column', 'Gutenberg metabox', 'entex');
	return $obj;
}
add_filter('entex_editor_core/cover', 'entex_editor_add_core_cover', 10, 1);

function entex_editor_add_core_group($obj){
	$obj['is-style-ua-border'] 	= 	esc_html_x('Border', 'Gutenberg metabox', 'entex');
	$obj['ua-absolute'] 		= 	esc_html_x('Position absolute', 'Gutenberg metabox', 'entex');
	$obj['ua-bottom'] 			= 	esc_html_x('Position bottom', 'Gutenberg metabox', 'entex');
	return $obj;
}
add_filter('entex_editor_core/group', 'entex_editor_add_core_group', 10, 1);

function entex_editor_add_validate($obj){
	$obj['is-style-ua-indent'] 			= 	'.is-root-container > p + p';
	$obj['is-style-ua-box-border'] 		= 	'.is-style-ua-box';
	$obj['ua-cover-column'] 			= 	'[class*=-location-]';
	$obj['is-style-ua-layer-caption'] 	= 	'*:not([data-align=center] > *)';
	$obj['is-style-ua-layer-heading'] 	= 	'.is-style-ua-layer-caption, .wp-block-cover';
	return $obj;
}
add_filter('entex_editor_validate', 'entex_editor_add_validate', 10, 1);


// -- END FILE -- //