<?php if(!defined('ABSPATH')) die();

// Updated 2021 07 29
// NOTE: We might remove custom image sizes
// AS standard 'small' size online is large today
// AND in favor for object-fit CSS property
// WE can simulate any thumbnail size with CSS values



if(!function_exists('entex_theme_setup_images')):
/* Create your own function to override in a child theme. */

function entex_theme_setup_images() {
	
	add_theme_support('custom-logo', array(
		'height'      => 300,
		'width'       => 300,
		'flex-width' => true,
		'flex-height' => true,
	));

	add_theme_support('post-thumbnails');
	entex_theme_setup_image_sizes();

	add_action('after_switch_theme', 'entex_theme_flush_images');

	// Add sizes to the 3.5 insert dialog
    add_filter('image_size_names_choose', 'entex_theme_image_size_names_choose');
	
	// Remove filters thats bang and destroys pure CSS solutions
	add_filter('img_caption_shortcode_width', '__return_false');
	add_filter('wp_calculate_image_srcset_meta', '__return_null');
	remove_filter('the_content', 'wp_make_content_images_responsive');

}
endif; // END Pluggable
add_action('after_setup_theme', 'entex_theme_setup_images');



/* Add sizes to the 3.5 insert dialog and Gutenberg */
function entex_theme_image_size_names_choose($sizes){
	
	/* Only WordPress public sizes are available as default */
	/* Lets add 'medium_large' as option as well */
	/* And rename for the user to be easy to understand as 'Normal' */
	
	global $_wp_additional_image_sizes;
	if(in_array('medium_large', get_intermediate_image_sizes())){
		$sizes['medium_large'] = esc_html_x('Normal', 'Admin', 'entex');
	}
	
    if(empty($_wp_additional_image_sizes)) return $sizes;
	
	/* Lets add custom added sizes, if any exists */
    foreach($_wp_additional_image_sizes as $id => $data){
        if(!isset($sizes[$id])) $sizes[$id] = ucfirst(str_replace('-', ' ', $id));
    }
	/* filter out post-thumbnail as we wanna use 'medium_large' as much as possible */
	if(isset($sizes['post-thumbnail'])) unset($sizes['post-thumbnail']);
	
	/* filter out hidden sizes as they exists in the array above */
	/* Entex theme doesnt need those 'responsive' images anyway */
	if(isset($sizes['1536x1536'])) unset($sizes['1536x1536']);
	if(isset($sizes['2048x2048'])) unset($sizes['2048x2048']);
	//die(var_dump($sizes));
	return $sizes;
}



/* -------------------- */
// IMAGE SIZE SETTINGS

if(!function_exists('entex_theme_setup_image_sizes')):
/* Create your own function to override in a child theme. */
function entex_theme_setup_image_sizes(){
	
	set_post_thumbnail_size(768, 0, true);
	add_image_size('entex-photo', 360, 450, true); // 4:5 

}
endif; // END Pluggable



if(!function_exists('entex_theme_flush_images')):
/* Create your own function to override in a child theme. */

function entex_theme_flush_images(){

	$in = 'post-thumbnail';
	update_option($in.'_size_w', 768);
	update_option($in.'_size_h', 0);
	update_option($in.'_crop', 1);
	
	$in = 'entex-photo';
	update_option($in.'_size_w', 360);
	update_option($in.'_size_h', 450);
	update_option($in.'_crop', 1);
	
	$in = 'thumbnail';
	update_option($in.'_size_w', 150);
	update_option($in.'_size_h', 150);
	update_option($in.'_crop', 1);
	
	$in = 'medium';
	update_option($in.'_size_w', 300);
	update_option($in.'_size_h', 300);
	update_option($in.'_crop', 1);

	$in = 'large';
	update_option($in.'_size_w', 1600);
	update_option($in.'_size_h', 0);
	update_option($in.'_crop', 0);
	
}
endif; // END Pluggable

if(defined('ENTEX_FLUSH_IMAGES')){
	add_action('after_setup_theme', 'entex_theme_flush_images');
}

/* ******************** */

// -- END FILE -- //